import { debounce } from 'lodash';

jQuery( function ( $ ) {
	/**
	 * Grid JS
	 */
	class dlpGrid {
		constructor() {
			$( document ).on(
				'click',
				'.dlp-grid-paginate-button',
				this.handleFetchGrid
			);
			$( document ).on(
				'click',
				'.dlp-grid-card-featured-img',
				this.openPhotoswipe
			);
			$( document ).on(
				'input',
				'.dlp-grid-search input[type="search"]',
				debounce( this.handleGridSearch, 300 )
			);
			$( document ).on(
				'click',
				'.dlp-grid-reset',
				this.handleGridReset
			);
		}

		/**
		 * Fetch Grid
		 */
		handleFetchGrid( event ) {
			const $this = $( this );

			if ( $this.hasClass( 'disabled' ) || $this.hasClass( 'current' ) ) {
				return;
			}

			const $grid_container = $this
				.parents( '.dlp-grid-container' )
				.first();
			const grid_id = $grid_container.attr( 'id' );
			const page_number = $( this ).data( 'page-number' );
			const blockConfig = {
				message: null,
				overlayCSS: {
					background: '#fff',
					opacity: 0.7,
				},
			};

			$grid_container.block( blockConfig );

			$.ajax( {
				url: dlp_grid_params.ajax_url,
				type: 'POST',
				data: {
					grid_id: grid_id,
					page_number: page_number,
					action: dlp_grid_params.ajax_action,
					_ajax_nonce: dlp_grid_params.ajax_nonce,
				},
				xhrFields: {
					withCredentials: true,
				},
			} ).done( function ( response ) {
				$( 'html, body' ).animate(
					{
						scrollTop: $grid_container.offset().top - 50,
					},
					300
				);

				dlpPopulateGridHtml( $grid_container, response );

				$grid_container.unblock();
			} );

			$grid_container.addClass( 'grid-loaded' );
		}

		/**
		 * Fetch Grid Search
		 */
		handleGridSearch( event ) {
			const $this = $( this );
			const $grid_container = $this
				.parents( '.dlp-grid-container' )
				.first();
			const grid_id = $grid_container.attr( 'id' );
			let searchQuery = $grid_container
				.find( '.dlp-grid-search input[type="search"]' )
				.val();
			const blockConfig = {
				message: null,
				overlayCSS: {
					background: '#fff',
					opacity: 0.7,
				},
			};

			// Sync Multiple Search Inputs
			$grid_container
				.find( '.dlp-grid-search input[type="search"]' )
				.not( this )
				.each( function ( index ) {
					$( this ).val( $this.val() );
				} );

			if ( searchQuery.length <= 3 ) {
				searchQuery = '';
			}

			$grid_container.block( blockConfig );

			$.ajax( {
				url: dlp_grid_params.ajax_url,
				type: 'POST',
				data: {
					grid_id: grid_id,
					search_query: searchQuery,
					page_number: 1,
					action: dlp_grid_params.ajax_action,
					_ajax_nonce: dlp_grid_params.ajax_nonce,
				},
				xhrFields: {
					withCredentials: true,
				},
			} ).done( function ( response ) {
				dlpPopulateGridHtml( $grid_container, response );

				$grid_container.unblock();
			} );

			$grid_container.addClass( 'grid-loaded' );
		}

		/**
		 * Fetch Grid Search
		 */
		handleGridReset( event ) {
			event.preventDefault();

			const $this = $( this );
			const $grid_container = $this
				.parents( '.dlp-grid-container' )
				.first();
			const grid_id = $grid_container.attr( 'id' );
			const $search_inputs = $grid_container.find(
				'.dlp-grid-search input[type="search"]'
			);

			const blockConfig = {
				message: null,
				overlayCSS: {
					background: '#fff',
					opacity: 0.7,
				},
			};

			$search_inputs.each( function ( index ) {
				$( this ).val( '' );
			} );

			$grid_container.block( blockConfig );

			$.ajax( {
				url: dlp_grid_params.ajax_url,
				type: 'POST',
				data: {
					grid_id: grid_id,
					search_query: '',
					page_number: 1,
					action: dlp_grid_params.ajax_action,
					_ajax_nonce: dlp_grid_params.ajax_nonce,
				},
				xhrFields: {
					withCredentials: true,
				},
			} ).done( function ( response ) {
				dlpPopulateGridHtml( $grid_container, response );

				$grid_container.unblock();
			} );
		}

		/**
		 * Open Lightbox
		 */
		openPhotoswipe( event ) {
			event.stopPropagation();

			const pswpElement = $( '.pswp' )[ 0 ];
			const $img = $( this ).find( 'img' );

			if ( $img.length < 1 ) {
				return;
			}

			const items = [
				{
					src: $img.attr( 'data-large_image' ),
					w: $img.attr( 'data-large_image_width' ),
					h: $img.attr( 'data-large_image_height' ),
					title:
						$img.attr( 'data-caption' ) &&
						$img.attr( 'data-caption' ).length
							? $img.attr( 'data-caption' )
							: $img.attr( 'title' ),
				},
			];

			const options = {
				index: 0,
				shareEl: false,
				closeOnScroll: false,
				history: false,
				hideAnimationDuration: 0,
				showAnimationDuration: 0,
			};

			// Initializes and opens PhotoSwipe
			let photoswipe = new PhotoSwipe(
				pswpElement,
				PhotoSwipeUI_Default,
				items,
				options
			);
			photoswipe.init();

			return false;
		}
	}

	function dlpPopulateGridHtml( $grid_container, response ) {
		const $grid_cards_container = $grid_container.find(
			'.dlp-grid-documents'
		);
		const $grid_pagination_footer = $grid_container.find(
			'footer .dlp-grid-pagination'
		);
		const $grid_pagination_header = $grid_container.find(
			'header .dlp-grid-pagination'
		);
		const $grid_totals_footer = $grid_container.find(
			'footer .dlp-grid-totals'
		);
		const $grid_totals_header = $grid_container.find(
			'header .dlp-grid-totals'
		);

		if ( response.grid ) {
			$grid_cards_container.replaceWith( response.grid );
		}

		if ( response.no_matching_documents ) {
			$grid_cards_container.html( response.no_matching_documents );
		}

		if ( $grid_pagination_footer.length > 0 && response.pagination ) {
			$grid_pagination_footer.replaceWith( response.pagination.footer );
		}

		if ( $grid_pagination_header.length > 0 && response.pagination ) {
			$grid_pagination_header.replaceWith( response.pagination.header );
		}

		if ( $grid_totals_footer.length > 0 && response.totals ) {
			$grid_totals_footer.replaceWith( response.totals.footer );
		}

		if ( $grid_totals_header.length > 0 && response.totals ) {
			$grid_totals_header.replaceWith( response.totals.header );
		}
	}

	/**
	 * Init dlpGrid.
	 */
	new dlpGrid();
} );
