<?php

namespace Barn2\Plugin\Document_Library_Pro\Shortcodes;

use Barn2\DLP_Lib\Registerable,
	Barn2\DLP_Lib\Service,
	Barn2\DLP_Lib\Conditional,
	Barn2\DLP_Lib\Util as Lib_Util;

defined( 'ABSPATH' ) || exit;

/**
 * This class handles the global doc search shortcode.
 *
 * @package   Barn2\document-library-pro
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class Document_Search implements Service, Registerable, Conditional {

	const SHORTCODE = 'doc_search';

	/**
	 * {@inheritdoc}
	 */
	public function is_required() {
		return Lib_Util::is_front_end();
	}

	/**
	 * {@inheritdoc}
	 */
	public function register() {
		add_shortcode( self::SHORTCODE, [ self::class, 'do_shortcode' ] );
	}


	/**
	 * Render the shortcode
	 *
	 * @param array $atts
	 * @param string $content
	 * @return string
	 */
	public static function do_shortcode( $atts, $content = '' ) {

		wp_enqueue_style( 'dlp-search-box' );

		$placeholder = isset( $atts['placeholder'] ) && ! empty( $atts['placeholder'] ) ? $atts['placeholder'] : esc_html__( 'Search documents...', 'document-library-pro' );
		$button_text = isset( $atts['button_text'] ) && ! empty( $atts['button_text'] ) ? $atts['button_text'] : esc_html__( 'Search', 'document-library-pro' );

		ob_start();

		?>
		<form role="search" method="get" class="dlp-document-search shortcode" action="<?php echo esc_attr( site_url() ); ?>">
			<label class="screen-reader-text" for="dlp-document-search-field"><?php esc_html_e( 'Document Search', 'document-library-pro' ); ?></label>
			<input type="search" class="dlp-document-search-field" placeholder="<?php echo esc_attr( $placeholder ); ?>" value="" name="dlp_search">
			<button type="submit" value="Search"><?php echo esc_html( $button_text ); ?></button>
		</form>
		<?php

		return ob_get_clean();
	}

}
