<?php
namespace Barn2\Plugin\Document_Library_Pro\Table_Data;

use Barn2\Plugin\Document_Library_Pro\Taxonomies,
	Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Data\Abstract_Table_Data,
	Barn2\Plugin\Document_Library_Pro\Posts_Table_Pro\Util\Util as PTP_Util,
	Barn2\Plugin\Document_Library_Pro\Util\Util;

defined( 'ABSPATH' ) || exit;

/**
 * Gets post data for the file type column
 *
 * @package   Barn2\document-library-pro
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class File_Type extends Abstract_Table_Data {

	private $taxonomy;

	/**
	 * Constructor.
	 *
	 * @param WP_Post $post
	 * @param Table_Args $args
	 */
	public function __construct( $post, $args ) {
		parent::__construct( $post, $args->links );

		$this->taxonomy        = Taxonomies::FILE_TYPE_SLUG;
		$this->search_on_click = $args->search_on_click;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_data() {
		$terms = '';
		$sep   = parent::get_separator( 'terms' );

		if ( array_intersect( [ 'all', $this->taxonomy ], $this->links ) && $this->search_on_click ) {
			$terms = Util::get_the_fake_linked_term_names( $this->post, $this->taxonomy, $sep );
		} else {
			$terms = PTP_Util::get_the_term_names( $this->post, $this->taxonomy, $sep );
		}

		return apply_filters( 'document_library_pro_data_file_type', $terms, $this->post );
	}
}
